@@ -346,7 +346,10 @@ quickSPC <- function(x, id = 'id', d = 'depths', n = 'name', m = 'soil_color', i
   
   # proportional horizon thickness
   # count labels
-  .counts <- stringr::str_count(.name.thick, .names)
+  .matches <- mapply(gregexpr, pattern = .names, text = .name.thick)
+  .counts <- sapply(.matches, length)
+  
+  
   # interval-unit thickness per label instance
   .thick <- .counts * interval
   
